@@ -192,6 +192,15 @@ public class RoomPanel extends BasePanel {
 			wb.update(target);
 		}
 
+		private CharSequence sendClientsOnInit() {
+			Client c = getClient();
+			StringBuilder res = new StringBuilder();
+			if (c.hasRight(Room.Right.MODERATOR) || !r.isHidden(RoomElement.USER_COUNT)) {
+				res.append(createAddClientJs(c));
+			}
+			return res;
+		}
+
 		private void initVideos(AjaxRequestTarget target) {
 			StringBuilder sb = new StringBuilder();
 			JSONArray streams = new JSONArray();
@@ -518,6 +527,9 @@ public class RoomPanel extends BasePanel {
 					case WB_PUT_FILE:
 						onWbPutFile((TextRoomMessage)m);
 						break;
+					case FILE_TREE_UPDATE:
+						onFileTreeUpdate(handler);
+						break;
 				}
 			}
 		}
@@ -604,6 +616,10 @@ public class RoomPanel extends BasePanel {
 		getWb().sendFileToWb(fileDao.getAny(obj.getLong("fileId")), obj.getBoolean("clean"));
 	}
 
+	private void onFileTreeUpdate(IPartialPageRequestHandler handler) {
+		sidebar.getFilesPanel().update(handler);
+	}
+
 	private String getQuickPollJs() {
 		return String.format("Room.quickPoll(%s);", qpollManager.toJson(r.getId()));
 	}
@@ -879,15 +895,6 @@ public class RoomPanel extends BasePanel {
 				.append(");");
 	}
 
-	private CharSequence sendClientsOnInit() {
-		Client c = getClient();
-		StringBuilder res = new StringBuilder();
-		if (c.hasRight(Room.Right.MODERATOR) || !r.isHidden(RoomElement.USER_COUNT)) {
-			res.append(createAddClientJs(c));
-		}
-		return res;
-	}
-
 	private CharSequence sendClientsOnUpdate() {
 		Client c = getClient();
 		StringBuilder res = new StringBuilder();
